Struct LowPowerOutput
Source pub struct LowPowerOutput<'d, const PIN: u8> { }
A GPIO output pin configured for low power operation
Create a new output pin for use by the low-power core
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.